Exception: GlobalID::Locator::RecordUnavailable

Inherits:
Error
  • Object
show all
Defined in:
lib/global_id/locator.rb

Overview

Raised by GlobalID::Locator.fetch when the record couldn’t be located due to any other error in the backend, such as a database connection error. The record may still exist, so retrying may succeed.